@@ -1,3 +1,38 @@
+#%%%%%%%%%%%%%%%%%%%%%%#
+#### MANY FUNCTIONS ####
+#%%%%%%%%%%%%%%%%%%%%%%#
+
+#' @noRd
+# Partial eta squared
+# Updated 02.09.2020
+partial.eta.sq <- function(ESS, RSS)
+{ESS / (ESS + RSS)}
+
+#' @noRd
+# Cohen's d
+# Updated 18.04.2021
+d <- function(samp1, samp2)
+{
+  # Means
+  m1 <- mean(samp1, na.rm = TRUE)
+  m2 <- mean(samp2, na.rm = TRUE)
+  
+  # Numerator
+  num <- m1 - m2
+  
+  # Standard deviations
+  sd1 <- sd(samp1, na.rm = TRUE)
+  sd2 <- sd(samp2, na.rm = TRUE)
+  
+  # Denominator
+  denom <- sqrt(
+    (sd1^2 + sd2^2) / 2
+  )
+  
+  return(abs(num / denom))
+  
+}
+
 #' Changes Bad Responses to NA
 #' 
 #' @description A sub-routine to determine whether responses are good or bad.
@@ -15,7 +50,7 @@
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Change Bad Responses----
+# Change Bad Responses
 # Updated 15.04.2020
 bad.response <- function (word, ...)
 {
@@ -61,7 +96,7 @@ bad.response <- function (word, ...)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Response matrix to binary matrix----
+# Response matrix to binary matrix
 # Updated 16.09.2020
 resp2bin <- function (resp)
 {
@@ -100,7 +135,7 @@ resp2bin <- function (resp)
 }
 
 #' @noRd
-# Sets up TMFG for bootstrap and permutation----
+# Sets up TMFG for bootstrap and permutation
 # Updated 01.09.2020
 tmfg_setup <- function(..., minCase)
 {
@@ -153,7 +188,7 @@ tmfg_setup <- function(..., minCase)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Binary to Response----
+# Binary to Response
 # Updated 16.09.2020
 bin2resp <- function (rmat, to.data.frame = FALSE)
 {
@@ -216,6 +251,199 @@ bin2resp <- function (rmat, to.data.frame = FALSE)
   return(mat)
 }
 
+
+#' Distance
+#' @description Computes distance matrix of the network
+#' 
+#' @param A An adjacency matrix of network data
+#' 
+#' @param weighted Is the network weighted?
+#' Defaults to \code{FALSE}.
+#' Set to \code{TRUE} for weighted measure of distance
+#' 
+#' @return A distance matrix of the network
+#' 
+#' @examples
+#' # Pearson's correlation only for CRAN checks
+#' A <- TMFG(neoOpen, normal = FALSE)$A
+#' 
+#' #Unweighted
+#' Du <- distance(A)
+#' 
+#' #Weighted
+#' Dw <- distance(A, weighted = TRUE)
+#' 
+#' @references 
+#' Rubinov, M., & Sporns, O. (2010). 
+#' Complex network measures of brain connectivity: Uses and interpretations. 
+#' \emph{NeuroImage}, \emph{52}, 1059-1069.
+#' 
+#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
+#' 
+#' @noRd
+# Distance (SemNeT)
+# Updated 02.09.2020
+distance<-function (A, weighted = FALSE)
+{
+  if(nrow(A)!=ncol(A))
+  {stop("Input not an adjacency matrix")}
+  if(!weighted)
+  {B<-ifelse(A!=0,1,0)
+  l<-1
+  Lpath<-B
+  D<-B
+  Idx<-matrix(TRUE,nrow=nrow(B),ncol=ncol(B))
+  while(any(Idx))
+  {
+    l<-l+1
+    Lpath<-(as.matrix(Lpath))%*%(as.matrix(B))
+    for(e in 1:nrow(Lpath))
+      for(w in 1:ncol(Lpath))
+        Idx[e,w]<-(Lpath[e,w]!=0&&(D[e,w]==0))
+    D[Idx]<-l
+  }
+  
+  D[!D]<-Inf
+  diag(D)<-0
+  }else if(weighted){
+    G<-ifelse(1/A==Inf,0,1/A)
+    
+    if(any(G==-Inf))
+    {G<-ifelse(G==-Inf,0,G)}
+    
+    if(any(!G==t(G)))
+    {if(max(abs(G-t(G)))<1e-10)
+    {G<-(G+G)/2}}
+    
+    n<-ncol(G)
+    D<-matrix(Inf,nrow=n,ncol=n)
+    diag(D)<-0
+    B<-matrix(0,nrow=n,ncol=n)
+    
+    for(u in 1:n)
+    {
+      S<-matrix(TRUE,nrow=n,ncol=1)
+      L1<-G
+      V<-u
+      while(TRUE)
+      {
+        S[V]<-0
+        L1[,V]<-0
+        for(v in V)
+        {
+          W<-which(L1[v,]!=0)
+          d<-apply(rbind(D[u,W],(D[u,v]+L1[v,W])),2,min)    
+          wi<-apply(rbind(D[u,W],(D[u,v]+L1[v,W])),2,which.min)
+          D[u,W]<-d
+          ind<-W[wi==2]
+          B[u,ind]<-B[u,v]+1
+        }
+        
+        minD<-suppressWarnings(min(D[u,S==TRUE]))
+        if(length(minD)==0||is.infinite(minD)){break}
+        
+        V<-which(D[u,]==minD)
+      }
+    }
+  }
+  
+  D<-ifelse(D==Inf,0,D)
+  
+  colnames(D)<-colnames(A)
+  row.names(D)<-colnames(A)
+  return(D)
+}
+#
+
+#' Binarize Network
+#' 
+#' @description Converts weighted adjacency matrix to a binarized adjacency matrix
+#' 
+#' @param A An adjacency matrix of network data (or an array of matrices)
+#' 
+#' @return Returns an adjacency matrix of 1's and 0's
+#' 
+#' @examples
+#' # Pearson's correlation only for CRAN checks
+#' A <- TMFG(neoOpen, normal = FALSE)$A
+#' 
+#' neoB <- binarize(A)
+#' 
+#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
+#' 
+#' @noRd
+# Binarize (SemNeT)
+# Updated 02.09.2020
+binarize <- function (A)
+{
+  A <- as.matrix(A)
+  bin <- ifelse(A!=0,1,0)
+  row.names(bin) <- row.names(A)
+  colnames(bin) <- colnames(A)
+  
+  return(bin)
+}
+
+#' Convert Network(s) to igraph's Format
+#' @description Converts single or multiple networks into \code{\link{igraph}}'s format for network analysis
+#' 
+#' @param A Adjacency matrix (network matrix) or brain connectivity array
+#' (from \code{\link[NetworkToolbox]{convertConnBrainMat}})
+#' 
+#' @param neural Is input a brain connectivity array (i.e., m x m x n)?
+#' Defaults to \code{FALSE}.
+#' Set to \code{TRUE} to convert each brain connectivity matrix
+#' 
+#' @return Returns a network matrix in \code{\link{igraph}}'s format or
+#' returns a list of brain connectivity matrices each of which have been
+#' convert to \code{\link{igraph}}'s format
+#' 
+#' @examples
+#' # Pearson's correlation only for CRAN checks
+#' A <- TMFG(neoOpen, normal = FALSE)$A
+#' 
+#' igraphNetwork <- convert2igraph(A)
+#' 
+#' \dontrun{ 
+#' neuralarray <- convertConnBrainMat()
+#' 
+#' igraphNeuralList <- convert2igraph(neuralarray, neural = TRUE)
+#' }
+#' 
+#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
+#' 
+#' @noRd
+# Convert matrices to igraph format (from NetworkToolbox)
+# Updated 02.09.2020
+convert2igraph <- function (A, neural = FALSE)
+{
+  if(!neural)
+  {
+    net <- igraph::as.igraph(qgraph::qgraph(A,DoNotPlot=TRUE))
+    return(net)
+  }else if(neural)
+  {
+    netlist <- list()
+    
+    n<-length(A)/nrow(A)/ncol(A)
+    
+    pb <- txtProgressBar(max=n, style = 3)
+    
+    for(i in 1:n)
+    {
+      netlist[[i]] <- igraph::as.igraph(qgraph::qgraph(A[,,i],DoNotPlot=TRUE))
+      setTxtProgressBar(pb, i)
+    }
+    close(pb)
+    
+    return(netlist)
+  }
+}
+
+#%%%%%%%%%%%%%#
+#### PLOTS ####
+#%%%%%%%%%%%%%#
+
 #' Organization function for \link[SemNeT]{plot.bootSemNeT}
 #' 
 #' @description A sub-routine used in \code{\link[SemNeT]{plot.bootSemNeT}}. Not to be used individually
@@ -269,7 +497,7 @@ bin2resp <- function (rmat, to.data.frame = FALSE)
 #' @importFrom stats qnorm
 #' 
 #' @noRd
-# Plot: Bootstrapped Network Statistics----
+# Plot: Bootstrapped Network Statistics
 #Updated 30.03.2020
 org.plot <- function (input, len, measures, name, groups, netmeas)
 {
@@ -288,9 +516,9 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
   {measures <- c("ASPL","CC","Q")
   }else{measures <- match.arg(measures,several.ok=TRUE)}
   
-  ###########################
-  #### FLAT VIOLIN PLOTS ####
-  ###########################
+  #%%%%%%%%%%%%%%%%%%%#
+  # FLAT VIOLIN PLOTS #
+  #%%%%%%%%%%%%%%%%%%%#
   
   #SEE: https://pdfs.semanticscholar.org/a38b/df3803b1cd00d57f69516be1d60a3c8688c9.pdf
   #AND: https://github.com/RainCloudPlots/RainCloudPlots
@@ -366,9 +594,9 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
             required_aes = c("x", "y")
     )
   
-  ###############################
-  #### SET UP DATA FOR PLOTS ####
-  ###############################
+  #%%%%%%%%%%%%%%%%%%%%%%%#
+  # SET UP DATA FOR PLOTS #
+  #%%%%%%%%%%%%%%%%%%%%%%%#
   
   # Initialize Proportion and Iterations
   perc <- vector("numeric", length = len)
@@ -487,9 +715,9 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
     plot.desc$prop <- as.factor(as.character(plot.desc$prop))
   }
   
-  ##############
-  #### PLOT ####
-  ##############
+  #%%%%%%#
+  # PLOT #
+  #%%%%%%#
   
   # Label Setups
   ## Measures
@@ -568,7 +796,8 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
       
       scale_fill_brewer(name = "Groups", labels = groups, palette = "Dark2") +
       
-      scale_x_discrete(label = name) +
+      scale_x_discrete(label = rev(name),
+                       limits = rev(levels(plot.mat.select$group))) +
       
       labs(title = paste("Bootstrap Case-wise Results:",netmeas,sep=" "),
            subtitle = paste(iter,"Samples",sep = " "),
@@ -591,7 +820,10 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
   
   return(pl)
 }
-#----
+
+#%%%%%%%%%%%%%%%%%%%%%%#
+#### RANDOM NETWORK ####
+#%%%%%%%%%%%%%%%%%%%%%%#
 
 #' Generates a Random Network
 #' 
@@ -624,7 +856,7 @@ org.plot <- function (input, len, measures, name, groups, netmeas)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Random Network----
+# Random Network
 # Updated 03.09.2020
 randnet <- function (nodes = NULL, edges = NULL, A = NULL)
 {
@@ -670,6 +902,28 @@ randnet <- function (nodes = NULL, edges = NULL, A = NULL)
   return(rand)
 }
 
+#%%%%%%%%%%%%%#
+#### TESTS ####
+#%%%%%%%%%%%%%#
+
+#' @noRd
+# Function to replicate rows
+# Updated 21.05.2020
+rep.rows <- function (mat, times)
+{
+  # New matrix
+  new.mat <- matrix(NA, nrow = 0, ncol = ncol(mat))
+  
+  # Loop through rows of matrix
+  for(i in 1:nrow(mat))
+  {new.mat <- rbind(new.mat, matrix(rep(mat[i,], times = times), ncol = ncol(mat), byrow = TRUE))}
+  
+  # Rename new matrix
+  colnames(new.mat) <- colnames(mat)
+  
+  return(new.mat)
+}
+
 #' Sub-routine function for \code{\link[SemNeT]{test.bootSemNeT}}
 #' 
 #' @description Computes statistical tests for partial bootstrapped
@@ -784,9 +1038,13 @@ randnet <- function (nodes = NULL, edges = NULL, A = NULL)
 #' @importFrom stats t.test aov TukeyHSD as.formula
 #' 
 #' @noRd
-# Test: Bootstrapped Network Statistics----
-# Updated 24.11.2020
-boot.one.test <- function (bootSemNeT.obj, measures = c("ASPL", "CC", "Q"), formula = NULL, groups = NULL)
+# Test: Bootstrapped Network Statistics
+# Updated 26.04.2021
+boot.one.test <- function (bootSemNeT.obj,
+                           test = c("ANCOVA", "ANOVA", "t-test"),
+                           measures = c("ASPL", "CC", "Q"),
+                           formula = NULL,
+                           groups = NULL)
 {
   #Check for 'bootSemNeT' object
   if(class(bootSemNeT.obj) != "bootSemNeT")
@@ -827,151 +1085,355 @@ boot.one.test <- function (bootSemNeT.obj, measures = c("ASPL", "CC", "Q"), form
   #Identify iterations
   iter <- bootSemNeT.obj$iter
   
-  ############################
-  #### SIGNIFICANCE TESTS ####
-  ############################
+  #%%%%%%%%%%%%%%%%%%%%#
+  # SIGNIFICANCE TESTS #
+  #%%%%%%%%%%%%%%%%%%%%#
   
   #Input results into list
   tests <- list()
   
-  #Loop through measures
-  for(i in 1:length(measures))
-  {
-    #Create ANCOVA data frame
-    for(j in 1:len)
+  #Check for test
+  if(test == "ANCOVA" | test == "ANOVA"){##ANCOVA or ANOVA
+    
+    #Loop through measures
+    for(i in 1:length(measures))
     {
-      #Insert measure values
-      meas <- bootSemNeT.obj[[paste(name[j],"Meas",sep="")]][measures[i],]
-      
-      # Nodes
-      #nodes <- unlist(lapply(bootSemNeT.obj[[paste(name[j],"Net",sep="")]], function(x){ncol(x)}))
-      
-      # Edges
-      edges <- unlist(lapply(bootSemNeT.obj[[paste(name[j],"Net",sep="")]], function(x){
-        net <- binarize(x)
-        diag(net) <- 0
-        return(sum(net) / 2)
-      }))
-      
-      #Initialize matrix
-      mat <- cbind(rep(name[j], length(meas)), meas, #nodes,
-                   edges)
-      
-      if(j != 1)
-      {new.mat <- rbind(new.mat, mat)
-      }else{new.mat <- mat}
-    }
-    
-    #Convert to data frame
-    aov.obj <- as.data.frame(new.mat, stringsAsFactors = FALSE)
-    colnames(aov.obj) <- c("Name", "Measure", #"Nodes",
-                           "Edges")
-    aov.obj$Name <- factor(as.character(aov.obj$Name))
-    aov.obj[,2:3] <- apply(aov.obj[,2:3], 2, function(x){as.numeric(as.character(x))})
-    
-    #Organize groups
-    aov.obj <- as.data.frame(cbind(aov.obj, rep.rows(groups, iter)), stringsAsFactors = FALSE)
-    
-    #Get column before groups
-    edge.col <- which(colnames(aov.obj) == "Edges")
-    
-    #Convert groups to factors
-    for(g in 1:ncol(groups))
-    {aov.obj[,(edge.col+g)] <- as.factor(as.character(aov.obj[,(edge.col+g)]))}
-    
-    #Remove variables that are all equal
-    keep.vars <- apply(aov.obj[,1:ncol(aov.obj)], 2, function(x){length(unique(x)) != 1})
-    aov.obj <- aov.obj[,keep.vars]
-    
-    #Group mean center
-    ## See Understanding and misunderstanding group mean centering: a commentary on Kelley et al.'s dangerous practice
-    ## Bell, A., Jones, K., & Fairbrother, M. (2018).
-    ## \emph{Quality & Quantity Volume} \emph{52}, 2031-2036.
-    ##https://doi.org/10.1007/s11135-017-0593-5
-    #if("Nodes" %in% names(aov.obj))
-    #{
-    #  for(g in 1:nrow(groups))
-    #  {
-    #    if(length(unique((aov.obj$Nodes[which(aov.obj$Group == groups[g,])]))) == 1){
-    #      aov.obj$Nodes[which(aov.obj$Group == groups[g,])] <- 0
-    #    }else{
-    #      aov.obj$Nodes[which(aov.obj$Group == groups[g,])] <- scale(aov.obj$Nodes[which(aov.obj$Group == groups[g,])])
-    #    }
-    #  }
-    #}
-    
-    if("Edges" %in% names(aov.obj))
-    {
-      for(g in 1:nrow(groups))
+      #Create ANCOVA data frame
+      for(j in 1:len)
       {
-        if(length(unique((aov.obj$Edges[which(aov.obj$Group == groups[g,])]))) == 1){
-          aov.obj$Edges[which(aov.obj$Group == groups[g,])] <- 0
-        }else{
-          aov.obj$Edges[which(aov.obj$Group == groups[g,])] <- scale(aov.obj$Edges[which(aov.obj$Group == groups[g,])])
+        #Insert measure values
+        meas <- bootSemNeT.obj[[paste(name[j],"Meas",sep="")]][measures[i],]
+        
+        # Nodes
+        #nodes <- unlist(lapply(bootSemNeT.obj[[paste(name[j],"Net",sep="")]], function(x){ncol(x)}))
+        
+        # Edges
+        edges <- unlist(lapply(bootSemNeT.obj[[paste(name[j],"Net",sep="")]], function(x){
+          net <- binarize(x)
+          diag(net) <- 0
+          return(sum(net) / 2)
+        }))
+        
+        #Initialize matrix
+        mat <- cbind(rep(name[j], length(meas)), meas, #nodes,
+                     edges)
+        
+        if(j != 1)
+        {new.mat <- rbind(new.mat, mat)
+        }else{new.mat <- mat}
+      }
+      
+      #Convert to data frame
+      aov.obj <- as.data.frame(new.mat, stringsAsFactors = FALSE)
+      colnames(aov.obj) <- c("Name", "Measure", #"Nodes",
+                             "Edges")
+      aov.obj$Name <- factor(as.character(aov.obj$Name))
+      aov.obj[,2:3] <- apply(aov.obj[,2:3], 2, function(x){as.numeric(as.character(x))})
+      
+      #Organize groups
+      aov.obj <- as.data.frame(cbind(aov.obj, rep.rows(groups, iter)), stringsAsFactors = FALSE)
+      
+      #Get column before groups
+      edge.col <- which(colnames(aov.obj) == "Edges")
+      
+      #Convert groups to factors
+      for(g in 1:ncol(groups))
+      {aov.obj[,(edge.col+g)] <- as.factor(as.character(aov.obj[,(edge.col+g)]))}
+      
+      #Remove variables that are all equal
+      keep.vars <- apply(aov.obj[,1:ncol(aov.obj)], 2, function(x){length(unique(x)) != 1})
+      aov.obj <- aov.obj[,keep.vars]
+      
+      #Group mean center
+      ## See Understanding and misunderstanding group mean centering: a commentary on Kelley et al.'s dangerous practice
+      ## Bell, A., Jones, K., & Fairbrother, M. (2018).
+      ## \emph{Quality & Quantity Volume} \emph{52}, 2031-2036.
+      ##https://doi.org/10.1007/s11135-017-0593-5
+      #if("Nodes" %in% names(aov.obj))
+      #{
+      #  for(g in 1:nrow(groups))
+      #  {
+      #    if(length(unique((aov.obj$Nodes[which(aov.obj$Group == groups[g,])]))) == 1){
+      #      aov.obj$Nodes[which(aov.obj$Group == groups[g,])] <- 0
+      #    }else{
+      #      aov.obj$Nodes[which(aov.obj$Group == groups[g,])] <- scale(aov.obj$Nodes[which(aov.obj$Group == groups[g,])])
+      #    }
+      #  }
+      #}
+      
+      if("Edges" %in% names(aov.obj))
+      {
+        for(g in 1:nrow(groups))
+        {
+          if(length(unique((aov.obj$Edges[which(aov.obj$Group == groups[g,])]))) == 1){
+            aov.obj$Edges[which(aov.obj$Group == groups[g,])] <- 0
+          }else{
+            aov.obj$Edges[which(aov.obj$Group == groups[g,])] <- scale(aov.obj$Edges[which(aov.obj$Group == groups[g,])])
+          }
         }
       }
+      
+      #ANOVA
+      if(test == "ANOVA"){
+        
+        if("Edges" %in% names(aov.obj)){
+          
+          aov.obj$Edges <- NULL
+          
+        }
+        
+      }
+      
+      #Formula
+      if(is.null(formula))
+      {formula <- paste("y ~", paste(colnames(groups), collapse = " + "))}
+      
+      #Replace 'y' with 'Measure'
+      formula <- gsub("y", "Measure", formula)
+      
+      #Split formula to add 'Nodes' and 'Edges'
+      split.formula <- unlist(strsplit(formula, split = "~"))
+      
+      #ANOVA formula
+      ##Catch Pathfinder Network method
+      #if(all(aov.obj$Nodes - aov.obj$Edges == 1))
+      #{aov.formula <- paste(split.formula[1], "~ ", paste(names(keep.vars)[4][keep.vars[4]], collapse = " + "), " +", split.formula[2], sep = "")
+      #}else{
+      #}
+      
+      if(test == "ANCOVA"){
+        aov.formula <- paste(split.formula[1], "~ ", paste(names(keep.vars)[3][keep.vars[3]], collapse = " + "), " +", split.formula[2], sep = "")
+      }else if(test == "ANOVA"){
+        aov.formula <- paste(split.formula[1], "~ ", split.formula[2], sep = "")
+      }
+      
+      #ANOVA
+      aov.test <- aov(as.formula(aov.formula), data = aov.obj)
+      
+      #ANCOVA
+      acov.test <- car::Anova(aov.test, type = "III")
+      
+      #Tidy ANCOVA
+      tidy.acov <- as.data.frame(broom::tidy(acov.test), stringsAsFactors = FALSE)
+      tidy.acov[,-1] <- round(apply(tidy.acov[,-1], 2, as.numeric), 3)
+      
+      #Get partial etas
+      etas <- round(unlist(lapply(acov.test$`Sum Sq`, partial.eta.sq, sum(acov.test$`Sum Sq`[length(acov.test$`Sum Sq`)])))[-c(1,length(acov.test$`Sum Sq`))], 3)
+      
+      #Attach etas to tidy ANCOVA
+      tidy.acov <- as.data.frame(cbind(tidy.acov, c(NA, etas, NA)), stringsAsFactors = FALSE)
+      
+      #Change column names
+      colnames(tidy.acov) <- c("Term", "Sum of Squares", "df", "F-statistic", "p-value", "Partial Eta Squared")
+      
+      #Change p-values
+      tidy.acov$`p-value` <- ifelse(tidy.acov$`p-value` < .001, "< .001", tidy.acov$`p-value`)
+      
+      # Convert NA to blank values
+      tidy.acov <- as.data.frame(apply(tidy.acov, 2, function(x){trimws(ifelse(is.na(x), "", x))}), stringsAsFactors = FALSE)
+      
+      #Get adjusted means
+      adj.means <- effects::allEffects(aov.test)
+      
+      #Insert ANCOVA
+      tests[[paste(measures[i])]]$ANCOVA <- tidy.acov
+      
+      #Insert adjusted means
+      tests[[paste(measures[i])]]$adjustedMeans <- adj.means[[which(names(adj.means) != "Nodes" & names(adj.means) != "Edges")]]
+      
+      #Get pairwise comparisons
+      if(nrow(groups) > 2){
+        
+        if(ncol(groups) == 1){
+          tests[[paste(measures[i])]]$HSD <- suppressWarnings(TukeyHSD(aov.test))$Group
+        }else{
+          tests[[paste(measures[i])]]$HSD <- unlist(suppressWarnings(TukeyHSD(aov.test)), recursive = FALSE)
+        }
+        
+      }
     }
     
-    #Formula
-    if(is.null(formula))
-    {formula <- paste("y ~", paste(colnames(groups), collapse = " + "))}
+  }else if(test == "t-test"){##t-test
     
-    #Replace 'y' with 'Measure'
-    formula <- gsub("y", "Measure", formula)
+    #Loop through measures
+    for(i in 1:length(measures)){
+      
+      #Group combinations
+      group.comb <- combn(groups, m = 2)
+      
+      #Result matrix
+      res.mat <- matrix(NA, nrow = ncol(group.comb), ncol = 11)
+      colnames(res.mat) <- c("df", "t-statistic", "p-value",
+                             "lower.ci", "upper.ci", "d",
+                             "Mean1", "SD1", "Mean2", "SD2",
+                             "Direction")
+      row.names(res.mat) <- 1:ncol(group.comb)
+      res.mat <- as.data.frame(res.mat)
+      
+      # Loop through groups
+      for(j in 1:ncol(group.comb)){
+        
+        # Names
+        one <- group.comb[1,j]
+        two <- group.comb[2,j]
+        
+        # Groups
+        group1 <- bootSemNeT.obj[[grep(paste(one, "Meas", sep = ""),
+                                            names(bootSemNeT.obj))]]
+        
+        group2 <- bootSemNeT.obj[[grep(paste(two, "Meas", sep = ""),
+                                       names(bootSemNeT.obj))]]
+        
+        #Compute t-test
+        summ <- t.test(group1[measures[i],],
+                       group2[measures[i],],
+                       var.equal = TRUE)
+        
+        # Input results
+        row.names(res.mat)[j] <- paste(one, two, sep = "--")
+        res.mat[j,1] <- summ$parameter
+        res.mat[j,2] <- round(summ$statistic, 3)
+        res.mat[j,3] <- ifelse(summ$p.value < .001, "< .001", round(summ$p.value, 3))
+        res.mat[j,4] <- round(summ$conf.int[1], 3)
+        res.mat[j,5] <- round(summ$conf.int[2], 3)
+        res.mat[j,6] <- round(d(group1[measures[i],],
+                                group2[measures[i],]), 3)
+        res.mat[j,7] <- round(mean(group1[measures[i],], na.rm = TRUE), 3)
+        res.mat[j,8] <- round(sd(group1[measures[i],], na.rm = TRUE), 3)
+        res.mat[j,9] <- round(mean(group2[measures[i],], na.rm = TRUE), 3)
+        res.mat[j,10] <- round(sd(group2[measures[i],], na.rm = TRUE), 3)
+        res.mat[j,11] <- ifelse(
+          summ$p.value > .05,
+          paste(one, "(1) = (2)", two, sep = ""),
+          ifelse(
+            mean(group1[measures[i],], na.rm = TRUE) >
+            mean(group2[measures[i],], na.rm = TRUE),
+            paste(one, "(1) > (2)", two, sep = ""),
+            paste(one, "(1) < (2)", two, sep = "")
+          )
+        )
+        
+      }
+      
+      tests[[paste(measures[i])]] <- res.mat
+      
+    }
     
-    #Split formula to add 'Nodes' and 'Edges'
-    split.formula <- unlist(strsplit(formula, split = "~"))
-    
-    #ANOVA formula
-    ##Catch Pathfinder Network method
-    #if(all(aov.obj$Nodes - aov.obj$Edges == 1))
-    #{aov.formula <- paste(split.formula[1], "~ ", paste(names(keep.vars)[4][keep.vars[4]], collapse = " + "), " +", split.formula[2], sep = "")
-    #}else{
-      aov.formula <- paste(split.formula[1], "~ ", paste(names(keep.vars)[3][keep.vars[3]], collapse = " + "), " +", split.formula[2], sep = "")
-    #}
-    
-    #ANOVA
-    aov.test <- aov(as.formula(aov.formula), data = aov.obj)
-    
-    #ANCOVA
-    acov.test <- car::Anova(aov.test, type = "III")
-    
-    #Tidy ANCOVA
-    tidy.acov <- as.data.frame(broom::tidy(acov.test), stringsAsFactors = FALSE)
-    tidy.acov[,-1] <- round(apply(tidy.acov[,-1], 2, as.numeric), 3)
-    
-    #Get partial etas
-    etas <- round(unlist(lapply(acov.test$`Sum Sq`, partial.eta.sq, sum(acov.test$`Sum Sq`[length(acov.test$`Sum Sq`)])))[-c(1,length(acov.test$`Sum Sq`))], 3)
-    
-    #Attach etas to tidy ANCOVA
-    tidy.acov <- as.data.frame(cbind(tidy.acov, c(NA, etas, NA)), stringsAsFactors = FALSE)
-    
-    #Change column names
-    colnames(tidy.acov) <- c("Term", "Sum of Squares", "df", "F-statistic", "p-value", "Partial Eta Squared")
-    
-    #Change p-values
-    tidy.acov$`p-value` <- ifelse(tidy.acov$`p-value` < .001, "< .001", tidy.acov$`p-value`)
-    
-    # Convert NA to blank values
-    tidy.acov <- as.data.frame(apply(tidy.acov, 2, function(x){trimws(ifelse(is.na(x), "", x))}), stringsAsFactors = FALSE)
-    
-    #Get adjusted means
-    adj.means <- effects::allEffects(aov.test)
-    
-    #Insert ANCOVA
-    tests[[paste(measures[i])]]$ANCOVA <- tidy.acov
-    
-    #Insert adjusted means
-    tests[[paste(measures[i])]]$adjustedMeans <- adj.means[[which(names(adj.means) != "Nodes" & names(adj.means) != "Edges")]]
-    
-    #Get pairwise comparisons
-    if(length(unique(groups[,1])) > 2)
-    {tests[[paste(measures[i])]]$HSD <- unlist(suppressWarnings(TukeyHSD(aov.test)), recursive = FALSE)}
   }
   
   return(tests)
 }
-#----
+
+#' @noRd
+# Function to organize t-test output
+# Updated 18.04.2021
+boot.t.org <- function(temp.res, groups, measures)
+{
+  if(ncol(groups) == 1){# Groups with no interactions
+    
+    if(nrow(groups) == 2){# Two groups
+      
+      # Initialize temporary table
+      temp.tab <- list()
+      
+      for(i in 1:length(temp.res)){
+        temp.tab[[i]] <- as.data.frame(
+          t(simplify2array(temp.res[[i]], higher = FALSE))
+        )
+      }
+      
+      # Name lists
+      names(temp.tab) <- names(temp.res)
+      
+      # Check table setup
+      if(length(temp.res) == 1){
+        return(temp.tab)
+      }else{
+        
+        # Make measure lists
+        res <- list()
+        
+        for(i in 1:length(measures)){
+          
+          # Get target measure
+          target <- lapply(temp.tab, function(x, measures){
+            x[measures,]
+          }, measures = measures[i])
+          
+          # Target table
+          target.table <- matrix(NA, nrow = 0, ncol = 11)
+          
+          for(j in 1:length(target)){
+            target.table <- rbind(target.table, target[[j]])
+          }
+          
+          # Change row names
+          row.names(target.table) <- names(temp.res)
+          
+          # Insert into results
+          res[[measures[[i]]]] <- target.table
+          
+        }
+        
+        return(res)
+        
+      }
+      
+    }else{# Many groups
+      
+      # Make measure lists
+      res <- list()
+      
+      for(i in 1:length(measures)){
+        
+        # Initialize temporary table
+        tab.temp <- matrix(NA, nrow = 0, ncol = 11)
+        
+        # Target measure
+        target <- lapply(temp.res, function(x, measures){
+          x[[measures]]
+        }, measures = measures[i])
+        
+        # Expand tables
+        for(j in 1:length(target)){
+          
+          # Target table
+          target.table <- target[[j]]
+          
+          # Change row names
+          row.names(target.table) <- paste(
+            row.names(target.table),
+            " [",
+            names(target)[j],
+            "] ",
+            sep = ""
+          )
+          
+          # Insert into table
+          tab.temp <- rbind(tab.temp, target.table)
+          
+        }
+        
+        # Insert temporary table into results
+        res[[measures[i]]] <- tab.temp
+        
+      }
+      
+      return(res)
+      
+    }
+    
+    
+  }#else{# Groups with interactions
+      # This doesn't make sense
+  #}
+  
+}
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%#
+#### NETWORK SUB-ROUTINES ####
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%#
+
 
 #' Co-occurence (sub-routine for Goni)
 #' 
@@ -989,7 +1451,7 @@ boot.one.test <- function (bootSemNeT.obj, measures = c("ASPL", "CC", "Q"), form
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Co-occurrence matrix----
+# Co-occurrence matrix
 # Updated 26.03.2020
 cooccur <- function(data, window = 2)
 {
@@ -1063,7 +1525,7 @@ cooccur <- function(data, window = 2)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Relative frequency----
+# Relative frequency
 # Updated 26.03.2020
 rel.freq <- function(data)
 {
@@ -1127,7 +1589,7 @@ rel.freq <- function(data)
 #' @importFrom stats binom.test
 #' 
 #' @noRd
-# Statistical Co-occurrence----
+# Statistical Co-occurrence
 # Updated 16.09.2020
 stat.cooccur <- function(data, window = 2, alpha = .05)
 {
@@ -1221,7 +1683,7 @@ stat.cooccur <- function(data, window = 2, alpha = .05)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Generalized Topological Overlap----
+# Generalized Topological Overlap
 # Updated 13.09.2020
 gtom <- function (A, steps = 2)
 {
@@ -1287,7 +1749,7 @@ gtom <- function (A, steps = 2)
 #' @importFrom stats hclust cutree as.dist
 #' 
 #' @noRd
-# Enrich Network----
+# Enrich Network
 # Updated 13.09.2020
 enrich.network <- function(A, GTOM)
 {
@@ -1366,219 +1828,9 @@ cosine <- function( x, y=NULL ) {
   
 }
 
-#' @noRd
-# Function to replicate rows----
-# Updated 21.05.2020
-rep.rows <- function (mat, times)
-{
-  # New matrix
-  new.mat <- matrix(NA, nrow = 0, ncol = ncol(mat))
-  
-  # Loop through rows of matrix
-  for(i in 1:nrow(mat))
-  {new.mat <- rbind(new.mat, matrix(rep(mat[i,], times = times), ncol = ncol(mat), byrow = TRUE))}
-  
-  # Rename new matrix
-  colnames(new.mat) <- colnames(mat)
-  
-  return(new.mat)
-}
-
-#' @noRd
-# Partial eta squared----
-# Updated 02.09.2020
-partial.eta.sq <- function(ESS, RSS)
-{ESS / (ESS + RSS)}
-
-#' Convert Network(s) to igraph's Format
-#' @description Converts single or multiple networks into \code{\link{igraph}}'s format for network analysis
-#' 
-#' @param A Adjacency matrix (network matrix) or brain connectivity array
-#' (from \code{\link[NetworkToolbox]{convertConnBrainMat}})
-#' 
-#' @param neural Is input a brain connectivity array (i.e., m x m x n)?
-#' Defaults to \code{FALSE}.
-#' Set to \code{TRUE} to convert each brain connectivity matrix
-#' 
-#' @return Returns a network matrix in \code{\link{igraph}}'s format or
-#' returns a list of brain connectivity matrices each of which have been
-#' convert to \code{\link{igraph}}'s format
-#' 
-#' @examples
-#' # Pearson's correlation only for CRAN checks
-#' A <- TMFG(neoOpen, normal = FALSE)$A
-#' 
-#' igraphNetwork <- convert2igraph(A)
-#' 
-#' \dontrun{ 
-#' neuralarray <- convertConnBrainMat()
-#' 
-#' igraphNeuralList <- convert2igraph(neuralarray, neural = TRUE)
-#' }
-#' 
-#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
-#' 
-#' @noRd
-# Convert matrices to igraph format (from NetworkToolbox)----
-# Updated 02.09.2020
-convert2igraph <- function (A, neural = FALSE)
-{
-  if(!neural)
-  {
-    net <- igraph::as.igraph(qgraph::qgraph(A,DoNotPlot=TRUE))
-    return(net)
-  }else if(neural)
-  {
-    netlist <- list()
-    
-    n<-length(A)/nrow(A)/ncol(A)
-    
-    pb <- txtProgressBar(max=n, style = 3)
-    
-    for(i in 1:n)
-    {
-      netlist[[i]] <- igraph::as.igraph(qgraph::qgraph(A[,,i],DoNotPlot=TRUE))
-      setTxtProgressBar(pb, i)
-    }
-    close(pb)
-    
-    return(netlist)
-  }
-}
-#----
-
-#' Distance
-#' @description Computes distance matrix of the network
-#' 
-#' @param A An adjacency matrix of network data
-#' 
-#' @param weighted Is the network weighted?
-#' Defaults to \code{FALSE}.
-#' Set to \code{TRUE} for weighted measure of distance
-#' 
-#' @return A distance matrix of the network
-#' 
-#' @examples
-#' # Pearson's correlation only for CRAN checks
-#' A <- TMFG(neoOpen, normal = FALSE)$A
-#' 
-#' #Unweighted
-#' Du <- distance(A)
-#' 
-#' #Weighted
-#' Dw <- distance(A, weighted = TRUE)
-#' 
-#' @references 
-#' Rubinov, M., & Sporns, O. (2010). 
-#' Complex network measures of brain connectivity: Uses and interpretations. 
-#' \emph{NeuroImage}, \emph{52}, 1059-1069.
-#' 
-#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
-#' 
-#' @noRd
-# Distance (SemNeT)----
-# Updated 02.09.2020
-distance<-function (A, weighted = FALSE)
-{
-  if(nrow(A)!=ncol(A))
-  {stop("Input not an adjacency matrix")}
-  if(!weighted)
-  {B<-ifelse(A!=0,1,0)
-  l<-1
-  Lpath<-B
-  D<-B
-  Idx<-matrix(TRUE,nrow=nrow(B),ncol=ncol(B))
-  while(any(Idx))
-  {
-    l<-l+1
-    Lpath<-(as.matrix(Lpath))%*%(as.matrix(B))
-    for(e in 1:nrow(Lpath))
-      for(w in 1:ncol(Lpath))
-        Idx[e,w]<-(Lpath[e,w]!=0&&(D[e,w]==0))
-    D[Idx]<-l
-  }
-  
-  D[!D]<-Inf
-  diag(D)<-0
-  }else if(weighted){
-    G<-ifelse(1/A==Inf,0,1/A)
-    
-    if(any(G==-Inf))
-    {G<-ifelse(G==-Inf,0,G)}
-    
-    if(any(!G==t(G)))
-    {if(max(abs(G-t(G)))<1e-10)
-    {G<-(G+G)/2}}
-    
-    n<-ncol(G)
-    D<-matrix(Inf,nrow=n,ncol=n)
-    diag(D)<-0
-    B<-matrix(0,nrow=n,ncol=n)
-    
-    for(u in 1:n)
-    {
-      S<-matrix(TRUE,nrow=n,ncol=1)
-      L1<-G
-      V<-u
-      while(TRUE)
-      {
-        S[V]<-0
-        L1[,V]<-0
-        for(v in V)
-        {
-          W<-which(L1[v,]!=0)
-          d<-apply(rbind(D[u,W],(D[u,v]+L1[v,W])),2,min)    
-          wi<-apply(rbind(D[u,W],(D[u,v]+L1[v,W])),2,which.min)
-          D[u,W]<-d
-          ind<-W[wi==2]
-          B[u,ind]<-B[u,v]+1
-        }
-        
-        minD<-suppressWarnings(min(D[u,S==TRUE]))
-        if(length(minD)==0||is.infinite(minD)){break}
-        
-        V<-which(D[u,]==minD)
-      }
-    }
-  }
-  
-  D<-ifelse(D==Inf,0,D)
-  
-  colnames(D)<-colnames(A)
-  row.names(D)<-colnames(A)
-  return(D)
-}
-#----
-
-#' Binarize Network
-#' 
-#' @description Converts weighted adjacency matrix to a binarized adjacency matrix
-#' 
-#' @param A An adjacency matrix of network data (or an array of matrices)
-#' 
-#' @return Returns an adjacency matrix of 1's and 0's
-#' 
-#' @examples
-#' # Pearson's correlation only for CRAN checks
-#' A <- TMFG(neoOpen, normal = FALSE)$A
-#' 
-#' neoB <- binarize(A)
-#' 
-#' @author Alexander Christensen <alexpaulchristensen@gmail.com>
-#' 
-#' @noRd
-# Binarize (SemNeT)----
-# Updated 02.09.2020
-binarize <- function (A)
-{
-  A <- as.matrix(A)
-  bin <- ifelse(A!=0,1,0)
-  row.names(bin) <- row.names(A)
-  colnames(bin) <- colnames(A)
-  
-  return(bin)
-}
-#----
+#%%%%%%%%%%%%%%%%%%%%%%%%#
+#### SYSTEM FUNCTIONS ####
+#%%%%%%%%%%%%%%%%%%%%%%%%#
 
 #' Stylizes Text
 #' 
@@ -1592,7 +1844,7 @@ binarize <- function (A)
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# Style text----
+# Style text
 # Updated 08.09.2020
 styletext <- function(text, defaults = c("bold", "italics", "highlight",
                                          "underline", "strikethrough"))
@@ -1632,7 +1884,7 @@ styletext <- function(text, defaults = c("bold", "italics", "highlight",
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @noRd
-# System Check----
+# System Check
 # Updated 08.09.2020
 system.check <- function (...)
 {
@@ -1651,4 +1903,4 @@ system.check <- function (...)
   res$TEXT <- TEXT
   
   return(res)
-}
\ No newline at end of file
+}
